<?php

namespace Teknisa\MAN\Controllers;

use Teknisa\MAN\Controllers\TeknisaCrud;
use Teknisa\Libs\Util\Masks\Masks;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;

class ContcorrBancoMasks extends TeknisaCrud{

    protected $dataSourceName = 'contcorr_banco_masks';
    protected $masks;

	public function __construct($crudService, $parameterBag, Masks $masks) {
		parent::__construct($crudService, $parameterBag);
		$this->masks = $masks;
	}
    
    /** 
     *  Essa função obrescreve a função find do teknisaCrud, com o objetico de depois da
     *  busca no banco de data, usar a classe Masks para criar um campo novo para cada row
     *  que tenha os códigos de agência e conta correte formatados com suas respctivas 
     *  mascaras, caso o numero de digitos da mascara seja igual o do registrado no banco,
     *  se não for não se aplica a mascara.
     *  
     *  @param $request vindo da requisição do frontend
     *  @param response que sera editado para retornar as rows para o frontend
     *  @return Rows do DataSet, do $response, com o campo de CDAGENCIA e CDCONTCORR
     *          formatados com a mascara, respectivamente CDAGENCIAMASK e CDCONTCORRMASK
     */
    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        parent::find($request, $response);
        $dataSets = $response->getDataSets();
        
        if(!empty($dataSets)){
            $rows = $dataSets[0]->getRows();
            for($i = 0; count($rows) > $i; $i++){

                //Retira pontos (.) e traços (-) da mascará para comparação de caracteres
                $matches = array();
                preg_match_all('/[^-.]*/',$rows[$i]['CDPICTAGEN'], $matches);
                $unmaskedString = implode('', $matches[0]);

                if(strlen($rows[$i]['CDAGENCIA']) === strlen($unmaskedString)) {
                    $rows[$i]['CDAGENCIAMASK'] = $this->masks->mask($rows[$i]['CDAGENCIA'], $rows[$i]['CDPICTAGEN']);
                } else {
                    $rows[$i]['CDAGENCIAMASK'] = $rows[$i]['CDAGENCIA'];
                }

                //Retira pontos (.) e traços (-) da mascará para comparação de caracteres
                $matches = array();
                preg_match_all('/[^-.]*/',$rows[$i]['CDPICTCONT'], $matches);
                $unmaskedString = implode('', $matches[0]);

                if (strlen($rows[$i]['CDCONTCORR']) === strlen($unmaskedString)) {
                    $rows[$i]['CDCONTCORRMASK'] = $this->masks->mask($rows[$i]['CDCONTCORR'], $rows[$i]['CDPICTCONT']);
                } else {
                    $rows[$i]['CDCONTCORRMASK'] = $rows[$i]['CDCONTCORR'];
                } 
            }
            $newDataSet = new DataSet($this->dataSourceName, $rows);
            $response->setDataSets(array($newDataSet));
        }
    }
    
}