<?php
namespace Teknisa\MAN\Controllers;

use Teknisa\MAN\Services\Ger97101FechamentoCupomService;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;

class Ger97101FechamentoCupomController {

    protected $fechamentoService;

    public function __construct(Ger97101FechamentoCupomService $fechamentoService) {
        $this->fechamentoService = $fechamentoService;
    }

    /*
     * Função para realizar o procedimento de aprovação de cupons pendentes.
     */
    public function aprovarCuponsFiscais(DTO\Request $request, DTO\Response $response) {
        try {
            $cupons = $request->getDataSet()->getRows();
            
            $valida = $cupons[1]['valida'];
            $cupons = $cupons[0];
            
            // Chama a função de aprovação, retornando quaisquer erros encontrados.
            $validationErrors = $this->fechamentoService->aprovarCuponsFiscais($cupons, $valida);

            if (!empty($validationErrors)) {
                $response->addDataset(new DataSet($validationErrors['key'], $validationErrors['data']));
            }
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function aprovarCuponsFiscaisPorLoja(DTO\Request $request, DTO\Response $response) {
        try {
            $cupons = $request->getDataSet()->getRows();
            
            $valida = $cupons[1]['valida'];
            $cupons = $cupons[0];
            
            // Chama a função de aprovação, retornando quaisquer erros encontrados.
            $validationErrors = $this->fechamentoService->aprovarCuponsFiscaisPorLoja($cupons, $valida);

            if (!empty($validationErrors)) {
                $response->addDataset(new DataSet($validationErrors['key'], $validationErrors['data']));
            }
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    /*
     * Função para realizar o procedimento de cancelamento de cupons aprovados.
     */
    public function cancelarCuponsFiscais(DTO\Request $request, DTO\Response $response) {
        try {
            $cupons = $request->getDataSet()->getRows();

            // Chama a função de cancelamento, retornando quaisquer erros encontrados.
            $validationData = $this->fechamentoService->cancelarCuponsFiscais($cupons);

            if (!empty($validationData)) {
                $response->addDataset(new DataSet('procedureErrors', $validationData));
            }
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function cancelarCuponsFiscaisPorLoja(DTO\Request $request, DTO\Response $response) {
        try {
            $cupons = $request->getDataSet()->getRows();

            // Chama a função de cancelamento, retornando quaisquer erros encontrados.
            $validationData = $this->fechamentoService->cancelarCuponsFiscaisPorLoja($cupons);

            if (!empty($validationData)) {
                $response->addDataset(new DataSet('procedureErrors', $validationData));
            }
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    /*
     * Função para realizar o procedimento de cancelamento da liberação para aprovação de cupons.
     */
    public function cancelarLiberacaoCuponsFiscais(DTO\Request $request, DTO\Response $response) {
        try {
            $cupons = $request->getDataSet()->getRows();

            $this->fechamentoService->cancelarLiberacaoCuponsFiscais($cupons);
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    /*
     * Função para realizar o procedimento de cancelamento de cupons aprovados.
     */
    public function conferenciaCuponsFiscais(DTO\Request $request, DTO\Response $response) {
        try {
            $requestData = $request->getRow();

            // Chama a função de cancelamento, retornando quaisquer valores
            // para exibição.
            $reportData = $this->fechamentoService->conferenciaCuponsFiscais($requestData["cupons"], $requestData["option"]);

            if (!empty($reportData)) {
                $response->addDataset(new DataSet('reportData', $reportData));
            }
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function conferenciaCuponsFiscaisPorLoja(DTO\Request $request, DTO\Response $response) {
        try {
            $requestData = $request->getRow();

            // Chama a função de cancelamento, retornando quaisquer valores
            // para exibição.
            $reportData = $this->fechamentoService->conferenciaCuponsFiscaisPorLoja($requestData["cupons"], $requestData["option"]);

            if (!empty($reportData)) {
                $response->addDataset(new DataSet('reportData', $reportData));
            }
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    /*
     * Função para realizar o procedimento de liberação de cupons para aprovação.
     */
    public function liberarAprovacaoCuponsFiscais(DTO\Request $request, DTO\Response $response) {
        try {
            $cupons = $request->getDataSet()->getRows();

            $this->fechamentoService->liberarAprovacaoCuponsFiscais($cupons);
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    /*
     * Função para realizar o procedimento de pré-validação de cupons.
     */
    public function preValidarCuponsFiscais(DTO\Request $request, DTO\Response $response) {
        try {
            $cupons = $request->getDataSet()->getRows();

            // Chama a função de validação, retornando quaisquer erros encontrados.
            $validationData = $this->fechamentoService->preValidarCuponsFiscais($cupons);

            if (!empty($validationData)) {
                $response->addDataset(new DataSet('preValidacaoErrors', $validationData));
            }
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function preValidarCuponsFiscaisPorLoja(DTO\Request $request, DTO\Response $response) {
        try {
            $cupons = $request->getDataSet()->getRows();

            // Chama a função de validação, retornando quaisquer erros encontrados.
            $validationData = $this->fechamentoService->preValidarCuponsFiscaisPorLoja($cupons);

            if (!empty($validationData)) {
                $response->addDataset(new DataSet('preValidacaoErrors', $validationData));
            }
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function limparbloqueioporLoja(DTO\Request $request, DTO\Response $response) {
        try {
           
            $row = $request->getRow();

            // Chama a função de validação, retornando quaisquer erros encontrados.
            $limparbloqueioporLoja = $this->fechamentoService->limparbloqueioporLoja($row);

        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function limparbloqueio(DTO\Request $request, DTO\Response $response) {
        try {
           
            $row = $request->getRow();

            // Chama a função de validação, retornando quaisquer erros encontrados.
            $limparbloqueio = $this->fechamentoService->limparbloqueio($row);

        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
}
