<?php

namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\Controller\CrudWithParameterBag;

class SelectMesaMultipleFiliLoja extends CrudWithParameterBag {
    const dataSourceConsumidor  = 'select_mesa_by_multiple_fililoja';
    
    protected $parameterBagColumnsConsumidor = array('CDFILIAL', 'TCDLOJA', 'CDLOJA');
    
    public function __construct ($parameterBag, Manager $dataSourceManager, $utilService) {
        $this->parameterBag             = $parameterBag;
        $this->dataSourceManager        = $dataSourceManager;
        $this->utilService              = $utilService;
    }
    
    public function find (DTO\Request\Filter $request, DTO\Response $response){
        $this->dataSourceName      = self::dataSourceConsumidor;
        $this->parameterBagColumns = $this->parameterBagColumnsConsumidor;
        $conditions                = $this->utilService->getParamsAsArray($request);
        $dataSourceFilter          = SelectMesaMultipleFiliLoja::prepareParameters($conditions);
        $requestDataSourceFilter = $request->getFilterCriteria()->getConditions();
        
        foreach($requestDataSourceFilter as $filter) {
            if($filter['operator'] === 'MAPPED_LIKE_ALL') {
                array_push($dataSourceFilter, $filter);
            }
        }
        
        $newRequest = new DTO\Request\Filter(
            new FilterCriteria(
                $this->dataSourceName,
                $dataSourceFilter,
                $request->getFilterCriteria()->getPage()
            ),
            $request->getMethod(),
            $request->getRoutePath(),
            $request->getUserId()
        );
        
        parent::find($newRequest, $response);
    }
    
    private function prepareParameters($conditions) {
        if(isset($conditions['CDFILIAL'])){
            $CDFILIAL = implode('_', $conditions['CDFILIAL']);
            $TCDFILIAL = NULL;
            
        } else {
            $CDFILIAL = NULL;
            $TCDFILIAL = 'T';
        }
        
        if(isset($conditions['CDLOJA']) && !!$conditions['CDLOJA']){
            $CDLOJA = implode('_', $conditions['CDLOJA']);
            $TCDLOJA = NULL;
            
        } else {
            $CDLOJA = NULL;
            $TCDLOJA = 'T';
        }
        
        $parameters = array(
            'CDFILIAL'  => $CDFILIAL,
            'TCDLOJA'   => $TCDLOJA,
            'CDLOJA'    => $CDLOJA
        );
        
        $dataSourceFilter = array();
        
        $dataSourceFilter[0] = array(
            "columnName" => 'CDFILIAL',
            "operator"   => "=",
            "value"      => $parameters['CDFILIAL']
        ); 
        $dataSourceFilter[1] = array(
            "columnName" => 'TCDLOJA',
            "operator"   => "=",
            "value"      => $parameters['TCDLOJA']
        );
        $dataSourceFilter[2] = array(
            "columnName" => 'CDLOJA',
            "operator"   => "=",
            "value"      => $parameters['CDLOJA']
        );
        
        return $dataSourceFilter;
    }
}